==> android-4.0.1.2-sources.jar: android/view/accessibility/AccessibilityRecord.java <==
package android.view.accessibility;
public class AccessibilityRecord
{
AccessibilityRecord() { throw new RuntimeException("Stub!"); }
public  void setSource(android.view.View source) { throw new RuntimeException("Stub!"); }
public  android.view.accessibility.AccessibilityNodeInfo getSource() { throw new RuntimeException("Stub!"); }
public  int getWindowId() { throw new RuntimeException("Stub!"); }
public  boolean isChecked() { throw new RuntimeException("Stub!"); }
public  void setChecked(boolean isChecked) { throw new RuntimeException("Stub!"); }
public  boolean isEnabled() { throw new RuntimeException("Stub!"); }
public  void setEnabled(boolean isEnabled) { throw new RuntimeException("Stub!"); }
public  boolean isPassword() { throw new RuntimeException("Stub!"); }
public  void setPassword(boolean isPassword) { throw new RuntimeException("Stub!"); }
public  boolean isFullScreen() { throw new RuntimeException("Stub!"); }
public  void setFullScreen(boolean isFullScreen) { throw new RuntimeException("Stub!"); }
public  boolean isScrollable() { throw new RuntimeException("Stub!"); }
public  void setScrollable(boolean scrollable) { throw new RuntimeException("Stub!"); }
public  int getItemCount() { throw new RuntimeException("Stub!"); }
public  void setItemCount(int itemCount) { throw new RuntimeException("Stub!"); }
public  int getCurrentItemIndex() { throw new RuntimeException("Stub!"); }
public  void setCurrentItemIndex(int currentItemIndex) { throw new RuntimeException("Stub!"); }
public  int getFromIndex() { throw new RuntimeException("Stub!"); }
public  void setFromIndex(int fromIndex) { throw new RuntimeException("Stub!"); }
public  int getToIndex() { throw new RuntimeException("Stub!"); }
public  void setToIndex(int toIndex) { throw new RuntimeException("Stub!"); }
public  int getScrollX() { throw new RuntimeException("Stub!"); }
public  void setScrollX(int scrollX) { throw new RuntimeException("Stub!"); }
public  int getScrollY() { throw new RuntimeException("Stub!"); }
public  void setScrollY(int scrollY) { throw new RuntimeException("Stub!"); }
public  int getAddedCount() { throw new RuntimeException("Stub!"); }
public  void setAddedCount(int addedCount) { throw new RuntimeException("Stub!"); }
public  int getRemovedCount() { throw new RuntimeException("Stub!"); }
public  void setRemovedCount(int removedCount) { throw new RuntimeException("Stub!"); }
public  java.lang.CharSequence getClassName() { throw new RuntimeException("Stub!"); }
public  void setClassName(java.lang.CharSequence className) { throw new RuntimeException("Stub!"); }
public  java.util.List<java.lang.CharSequence> getText() { throw new RuntimeException("Stub!"); }
public  java.lang.CharSequence getBeforeText() { throw new RuntimeException("Stub!"); }
public  void setBeforeText(java.lang.CharSequence beforeText) { throw new RuntimeException("Stub!"); }
public  java.lang.CharSequence getContentDescription() { throw new RuntimeException("Stub!"); }
public  void setContentDescription(java.lang.CharSequence contentDescription) { throw new RuntimeException("Stub!"); }
public  android.os.Parcelable getParcelableData() { throw new RuntimeException("Stub!"); }
public  void setParcelableData(android.os.Parcelable parcelableData) { throw new RuntimeException("Stub!"); }
public static  android.view.accessibility.AccessibilityRecord obtain(android.view.accessibility.AccessibilityRecord record) { throw new RuntimeException("Stub!"); }
public static  android.view.accessibility.AccessibilityRecord obtain() { throw new RuntimeException("Stub!"); }
public  void recycle() { throw new RuntimeException("Stub!"); }
public  java.lang.String toString() { throw new RuntimeException("Stub!"); }
}

==> android-4.1.1.4-sources.jar: android/view/accessibility/AccessibilityRecord.java <==
package android.view.accessibility;
public class AccessibilityRecord
{
AccessibilityRecord() { throw new RuntimeException("Stub!"); }
public  void setSource(android.view.View source) { throw new RuntimeException("Stub!"); }
public  void setSource(android.view.View root, int virtualDescendantId) { throw new RuntimeException("Stub!"); }
public  android.view.accessibility.AccessibilityNodeInfo getSource() { throw new RuntimeException("Stub!"); }
public  int getWindowId() { throw new RuntimeException("Stub!"); }
public  boolean isChecked() { throw new RuntimeException("Stub!"); }
public  void setChecked(boolean isChecked) { throw new RuntimeException("Stub!"); }
public  boolean isEnabled() { throw new RuntimeException("Stub!"); }
public  void setEnabled(boolean isEnabled) { throw new RuntimeException("Stub!"); }
public  boolean isPassword() { throw new RuntimeException("Stub!"); }
public  void setPassword(boolean isPassword) { throw new RuntimeException("Stub!"); }
public  boolean isFullScreen() { throw new RuntimeException("Stub!"); }
public  void setFullScreen(boolean isFullScreen) { throw new RuntimeException("Stub!"); }
public  boolean isScrollable() { throw new RuntimeException("Stub!"); }
public  void setScrollable(boolean scrollable) { throw new RuntimeException("Stub!"); }
public  int getItemCount() { throw new RuntimeException("Stub!"); }
public  void setItemCount(int itemCount) { throw new RuntimeException("Stub!"); }
public  int getCurrentItemIndex() { throw new RuntimeException("Stub!"); }
public  void setCurrentItemIndex(int currentItemIndex) { throw new RuntimeException("Stub!"); }
public  int getFromIndex() { throw new RuntimeException("Stub!"); }
public  void setFromIndex(int fromIndex) { throw new RuntimeException("Stub!"); }
public  int getToIndex() { throw new RuntimeException("Stub!"); }
public  void setToIndex(int toIndex) { throw new RuntimeException("Stub!"); }
public  int getScrollX() { throw new RuntimeException("Stub!"); }
public  void setScrollX(int scrollX) { throw new RuntimeException("Stub!"); }
public  int getScrollY() { throw new RuntimeException("Stub!"); }
public  void setScrollY(int scrollY) { throw new RuntimeException("Stub!"); }
public  int getMaxScrollX() { throw new RuntimeException("Stub!"); }
public  void setMaxScrollX(int maxScrollX) { throw new RuntimeException("Stub!"); }
public  int getMaxScrollY() { throw new RuntimeException("Stub!"); }
public  void setMaxScrollY(int maxScrollY) { throw new RuntimeException("Stub!"); }
public  int getAddedCount() { throw new RuntimeException("Stub!"); }
public  void setAddedCount(int addedCount) { throw new RuntimeException("Stub!"); }
public  int getRemovedCount() { throw new RuntimeException("Stub!"); }
public  void setRemovedCount(int removedCount) { throw new RuntimeException("Stub!"); }
public  java.lang.CharSequence getClassName() { throw new RuntimeException("Stub!"); }
public  void setClassName(java.lang.CharSequence className) { throw new RuntimeException("Stub!"); }
public  java.util.List<java.lang.CharSequence> getText() { throw new RuntimeException("Stub!"); }
public  java.lang.CharSequence getBeforeText() { throw new RuntimeException("Stub!"); }
public  void setBeforeText(java.lang.CharSequence beforeText) { throw new RuntimeException("Stub!"); }
public  java.lang.CharSequence getContentDescription() { throw new RuntimeException("Stub!"); }
public  void setContentDescription(java.lang.CharSequence contentDescription) { throw new RuntimeException("Stub!"); }
public  android.os.Parcelable getParcelableData() { throw new RuntimeException("Stub!"); }
public  void setParcelableData(android.os.Parcelable parcelableData) { throw new RuntimeException("Stub!"); }
public static  android.view.accessibility.AccessibilityRecord obtain(android.view.accessibility.AccessibilityRecord record) { throw new RuntimeException("Stub!"); }
public static  android.view.accessibility.AccessibilityRecord obtain() { throw new RuntimeException("Stub!"); }
public  void recycle() { throw new RuntimeException("Stub!"); }
public  java.lang.String toString() { throw new RuntimeException("Stub!"); }
}
